# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/billing_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/billing_account.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/billing/v1/billing_account.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x01\n\x0e\x42illingAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63ountry_code\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\x12\x0f\n\x07\x62\x61lance\x18\x07 \x01(\tBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_BILLINGACCOUNT = _descriptor.Descriptor(
  name='BillingAccount',
  full_name='yandex.cloud.billing.v1.BillingAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.BillingAccount.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.billing.v1.BillingAccount.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.billing.v1.BillingAccount.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='yandex.cloud.billing.v1.BillingAccount.country_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='yandex.cloud.billing.v1.BillingAccount.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='yandex.cloud.billing.v1.BillingAccount.active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='yandex.cloud.billing.v1.BillingAccount.balance', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=271,
)

_BILLINGACCOUNT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['BillingAccount'] = _BILLINGACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BillingAccount = _reflection.GeneratedProtocolMessageType('BillingAccount', (_message.Message,), {
  'DESCRIPTOR' : _BILLINGACCOUNT,
  '__module__' : 'yandex.cloud.billing.v1.billing_account_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.BillingAccount)
  })
_sym_db.RegisterMessage(BillingAccount)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.datasphere.v1 import app_token_service_pb2 as yandex_dot_cloud_dot_datasphere_dot_v1_dot_app__token__service__pb2


class AppTokenServiceStub(object):
    """A set of methods for managing app tokens.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Validate = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.AppTokenService/Validate',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_app__token__service__pb2.AppTokenValidateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class AppTokenServiceServicer(object):
    """A set of methods for managing app tokens.
    """

    def Validate(self, request, context):
        """Validates app token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AppTokenServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Validate': grpc.unary_unary_rpc_method_handler(
                    servicer.Validate,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_app__token__service__pb2.AppTokenValidateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.datasphere.v1.AppTokenService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AppTokenService(object):
    """A set of methods for managing app tokens.
    """

    @staticmethod
    def Validate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.AppTokenService/Validate',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_app__token__service__pb2.AppTokenValidateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/placement_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/placement_group.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/compute/v1/placement_group.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe9\x02\n\x0ePlacementGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.compute.v1.PlacementGroup.LabelsEntry\x12U\n\x19spread_placement_strategy\x18\x07 \x01(\x0b\x32\x30.yandex.cloud.compute.v1.SpreadPlacementStrategyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1a\n\x12placement_strategy\x12\x04\xc0\xc1\x31\x01\"\x19\n\x17SpreadPlacementStrategyBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_PLACEMENTGROUP_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.PlacementGroup.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.PlacementGroup.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.PlacementGroup.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=472,
)

_PLACEMENTGROUP = _descriptor.Descriptor(
  name='PlacementGroup',
  full_name='yandex.cloud.compute.v1.PlacementGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.compute.v1.PlacementGroup.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.PlacementGroup.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.compute.v1.PlacementGroup.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.PlacementGroup.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.PlacementGroup.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.PlacementGroup.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spread_placement_strategy', full_name='yandex.cloud.compute.v1.PlacementGroup.spread_placement_strategy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PLACEMENTGROUP_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='placement_strategy', full_name='yandex.cloud.compute.v1.PlacementGroup.placement_strategy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=139,
  serialized_end=500,
)


_SPREADPLACEMENTSTRATEGY = _descriptor.Descriptor(
  name='SpreadPlacementStrategy',
  full_name='yandex.cloud.compute.v1.SpreadPlacementStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=527,
)

_PLACEMENTGROUP_LABELSENTRY.containing_type = _PLACEMENTGROUP
_PLACEMENTGROUP.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLACEMENTGROUP.fields_by_name['labels'].message_type = _PLACEMENTGROUP_LABELSENTRY
_PLACEMENTGROUP.fields_by_name['spread_placement_strategy'].message_type = _SPREADPLACEMENTSTRATEGY
_PLACEMENTGROUP.oneofs_by_name['placement_strategy'].fields.append(
  _PLACEMENTGROUP.fields_by_name['spread_placement_strategy'])
_PLACEMENTGROUP.fields_by_name['spread_placement_strategy'].containing_oneof = _PLACEMENTGROUP.oneofs_by_name['placement_strategy']
DESCRIPTOR.message_types_by_name['PlacementGroup'] = _PLACEMENTGROUP
DESCRIPTOR.message_types_by_name['SpreadPlacementStrategy'] = _SPREADPLACEMENTSTRATEGY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlacementGroup = _reflection.GeneratedProtocolMessageType('PlacementGroup', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLACEMENTGROUP_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.placement_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.PlacementGroup.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _PLACEMENTGROUP,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.PlacementGroup)
  })
_sym_db.RegisterMessage(PlacementGroup)
_sym_db.RegisterMessage(PlacementGroup.LabelsEntry)

SpreadPlacementStrategy = _reflection.GeneratedProtocolMessageType('SpreadPlacementStrategy', (_message.Message,), {
  'DESCRIPTOR' : _SPREADPLACEMENTSTRATEGY,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.SpreadPlacementStrategy)
  })
_sym_db.RegisterMessage(SpreadPlacementStrategy)


DESCRIPTOR._options = None
_PLACEMENTGROUP_LABELSENTRY._options = None
_PLACEMENTGROUP.oneofs_by_name['placement_strategy']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/sqlserver/v1/database_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.sqlserver.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/sqlserver/v1/database_service.proto',
  package='yandex.cloud.mdb.sqlserver.v1',
  syntax='proto3',
  serialized_options=b'\n!yandex.cloud.api.mdb.sqlserver.v1B\004PSDSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4yandex/cloud/mdb/sqlserver/v1/database_service.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/mdb/sqlserver/v1/database.proto\"m\n\x12GetDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"v\n\x14ListDatabasesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x15ListDatabasesResponse\x12:\n\tdatabases\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x83\x01\n\x15\x43reateDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12H\n\rdatabase_spec\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.sqlserver.v1.DatabaseSpecB\x04\xe8\xc7\x31\x01\"C\n\x16\x43reateDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"p\n\x15\x44\x65leteDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"C\n\x16\x44\x65leteDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\xbd\x01\n\x16RestoreDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rfrom_database\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\"\x86\x01\n\x17RestoreDatabaseMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rfrom_database\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"\x9b\x01\n\x1bImportDatabaseBackupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\x12\x13\n\x05\x66iles\x18\x05 \x03(\tB\x04\xe8\xc7\x31\x01\"\x7f\n\x1cImportDatabaseBackupMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\"\x96\x01\n\x1b\x45xportDatabaseBackupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\"\x7f\n\x1c\x45xportDatabaseBackupMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t2\xbe\x0b\n\x0f\x44\x61tabaseService\x12\xac\x01\n\x03Get\x12\x31.yandex.cloud.mdb.sqlserver.v1.GetDatabaseRequest\x1a\'.yandex.cloud.mdb.sqlserver.v1.Database\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}\x12\xac\x01\n\x04List\x12\x33.yandex.cloud.mdb.sqlserver.v1.ListDatabasesRequest\x1a\x34.yandex.cloud.mdb.sqlserver.v1.ListDatabasesResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/mdb/sqlserver/v1/clusters/{cluster_id}/databases\x12\xc5\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.sqlserver.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"b\x82\xd3\xe4\x93\x02\x36\"1/mdb/sqlserver/v1/clusters/{cluster_id}/databases:\x01*\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x12\xd0\x01\n\x07Restore\x12\x35.yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"k\x82\xd3\xe4\x93\x02>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/databases:restore:\x01*\xb2\xd2*#\n\x17RestoreDatabaseMetadata\x12\x08\x44\x61tabase\x12\xde\x01\n\x0cImportBackup\x12:.yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest\x1a!.yandex.cloud.operation.Operation\"o\x82\xd3\xe4\x93\x02=\"8/mdb/sqlserver/v1/clusters/{cluster_id}/databases:import:\x01*\xb2\xd2*(\n\x1cImportDatabaseBackupMetadata\x12\x08\x44\x61tabase\x12\xee\x01\n\x0c\x45xportBackup\x12:.yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\x82\xd3\xe4\x93\x02M\"H/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}:export:\x01*\xb2\xd2*(\n\x1c\x45xportDatabaseBackupMetadata\x12\x08\x44\x61tabase\x12\xdf\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"|\x82\xd3\xe4\x93\x02\x43*A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.EmptyBv\n!yandex.cloud.api.mdb.sqlserver.v1B\x04PSDSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2.DESCRIPTOR,])




_GETDATABASEREQUEST = _descriptor.Descriptor(
  name='GetDatabaseRequest',
  full_name='yandex.cloud.mdb.sqlserver.v1.GetDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.GetDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.GetDatabaseRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=410,
)


_LISTDATABASESREQUEST = _descriptor.Descriptor(
  name='ListDatabasesRequest',
  full_name='yandex.cloud.mdb.sqlserver.v1.ListDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.ListDatabasesRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.sqlserver.v1.ListDatabasesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.sqlserver.v1.ListDatabasesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=530,
)


_LISTDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListDatabasesResponse',
  full_name='yandex.cloud.mdb.sqlserver.v1.ListDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='yandex.cloud.mdb.sqlserver.v1.ListDatabasesResponse.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.sqlserver.v1.ListDatabasesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=640,
)


_CREATEDATABASEREQUEST = _descriptor.Descriptor(
  name='CreateDatabaseRequest',
  full_name='yandex.cloud.mdb.sqlserver.v1.CreateDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.CreateDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_spec', full_name='yandex.cloud.mdb.sqlserver.v1.CreateDatabaseRequest.database_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=774,
)


_CREATEDATABASEMETADATA = _descriptor.Descriptor(
  name='CreateDatabaseMetadata',
  full_name='yandex.cloud.mdb.sqlserver.v1.CreateDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.CreateDatabaseMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.CreateDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=843,
)


_DELETEDATABASEREQUEST = _descriptor.Descriptor(
  name='DeleteDatabaseRequest',
  full_name='yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=957,
)


_DELETEDATABASEMETADATA = _descriptor.Descriptor(
  name='DeleteDatabaseMetadata',
  full_name='yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1026,
)


_RESTOREDATABASEREQUEST = _descriptor.Descriptor(
  name='RestoreDatabaseRequest',
  full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_database', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest.from_database', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest.backup_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest.time', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1029,
  serialized_end=1218,
)


_RESTOREDATABASEMETADATA = _descriptor.Descriptor(
  name='RestoreDatabaseMetadata',
  full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_database', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseMetadata.from_database', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup_id', full_name='yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseMetadata.backup_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1221,
  serialized_end=1355,
)


_IMPORTDATABASEBACKUPREQUEST = _descriptor.Descriptor(
  name='ImportDatabaseBackupRequest',
  full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3_bucket', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest.s3_bucket', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3_path', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest.s3_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='files', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest.files', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1358,
  serialized_end=1513,
)


_IMPORTDATABASEBACKUPMETADATA = _descriptor.Descriptor(
  name='ImportDatabaseBackupMetadata',
  full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3_bucket', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupMetadata.s3_bucket', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3_path', full_name='yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupMetadata.s3_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1642,
)


_EXPORTDATABASEBACKUPREQUEST = _descriptor.Descriptor(
  name='ExportDatabaseBackupRequest',
  full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3_bucket', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest.s3_bucket', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3_path', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest.s3_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest.prefix', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1645,
  serialized_end=1795,
)


_EXPORTDATABASEBACKUPMETADATA = _descriptor.Descriptor(
  name='ExportDatabaseBackupMetadata',
  full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3_bucket', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupMetadata.s3_bucket', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s3_path', full_name='yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupMetadata.s3_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=1924,
)

_LISTDATABASESRESPONSE.fields_by_name['databases'].message_type = yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2._DATABASE
_CREATEDATABASEREQUEST.fields_by_name['database_spec'].message_type = yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2._DATABASESPEC
_RESTOREDATABASEREQUEST.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['GetDatabaseRequest'] = _GETDATABASEREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesRequest'] = _LISTDATABASESREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesResponse'] = _LISTDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['CreateDatabaseRequest'] = _CREATEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['CreateDatabaseMetadata'] = _CREATEDATABASEMETADATA
DESCRIPTOR.message_types_by_name['DeleteDatabaseRequest'] = _DELETEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatabaseMetadata'] = _DELETEDATABASEMETADATA
DESCRIPTOR.message_types_by_name['RestoreDatabaseRequest'] = _RESTOREDATABASEREQUEST
DESCRIPTOR.message_types_by_name['RestoreDatabaseMetadata'] = _RESTOREDATABASEMETADATA
DESCRIPTOR.message_types_by_name['ImportDatabaseBackupRequest'] = _IMPORTDATABASEBACKUPREQUEST
DESCRIPTOR.message_types_by_name['ImportDatabaseBackupMetadata'] = _IMPORTDATABASEBACKUPMETADATA
DESCRIPTOR.message_types_by_name['ExportDatabaseBackupRequest'] = _EXPORTDATABASEBACKUPREQUEST
DESCRIPTOR.message_types_by_name['ExportDatabaseBackupMetadata'] = _EXPORTDATABASEBACKUPMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDatabaseRequest = _reflection.GeneratedProtocolMessageType('GetDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.GetDatabaseRequest)
  })
_sym_db.RegisterMessage(GetDatabaseRequest)

ListDatabasesRequest = _reflection.GeneratedProtocolMessageType('ListDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESREQUEST,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.ListDatabasesRequest)
  })
_sym_db.RegisterMessage(ListDatabasesRequest)

ListDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESPONSE,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.ListDatabasesResponse)
  })
_sym_db.RegisterMessage(ListDatabasesResponse)

CreateDatabaseRequest = _reflection.GeneratedProtocolMessageType('CreateDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.CreateDatabaseRequest)
  })
_sym_db.RegisterMessage(CreateDatabaseRequest)

CreateDatabaseMetadata = _reflection.GeneratedProtocolMessageType('CreateDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.CreateDatabaseMetadata)
  })
_sym_db.RegisterMessage(CreateDatabaseMetadata)

DeleteDatabaseRequest = _reflection.GeneratedProtocolMessageType('DeleteDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseRequest)
  })
_sym_db.RegisterMessage(DeleteDatabaseRequest)

DeleteDatabaseMetadata = _reflection.GeneratedProtocolMessageType('DeleteDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseMetadata)
  })
_sym_db.RegisterMessage(DeleteDatabaseMetadata)

RestoreDatabaseRequest = _reflection.GeneratedProtocolMessageType('RestoreDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTOREDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest)
  })
_sym_db.RegisterMessage(RestoreDatabaseRequest)

RestoreDatabaseMetadata = _reflection.GeneratedProtocolMessageType('RestoreDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESTOREDATABASEMETADATA,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseMetadata)
  })
_sym_db.RegisterMessage(RestoreDatabaseMetadata)

ImportDatabaseBackupRequest = _reflection.GeneratedProtocolMessageType('ImportDatabaseBackupRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTDATABASEBACKUPREQUEST,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest)
  })
_sym_db.RegisterMessage(ImportDatabaseBackupRequest)

ImportDatabaseBackupMetadata = _reflection.GeneratedProtocolMessageType('ImportDatabaseBackupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTDATABASEBACKUPMETADATA,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupMetadata)
  })
_sym_db.RegisterMessage(ImportDatabaseBackupMetadata)

ExportDatabaseBackupRequest = _reflection.GeneratedProtocolMessageType('ExportDatabaseBackupRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTDATABASEBACKUPREQUEST,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest)
  })
_sym_db.RegisterMessage(ExportDatabaseBackupRequest)

ExportDatabaseBackupMetadata = _reflection.GeneratedProtocolMessageType('ExportDatabaseBackupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTDATABASEBACKUPMETADATA,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupMetadata)
  })
_sym_db.RegisterMessage(ExportDatabaseBackupMetadata)


DESCRIPTOR._options = None
_GETDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_GETDATABASEREQUEST.fields_by_name['database_name']._options = None
_LISTDATABASESREQUEST.fields_by_name['cluster_id']._options = None
_LISTDATABASESREQUEST.fields_by_name['page_size']._options = None
_LISTDATABASESREQUEST.fields_by_name['page_token']._options = None
_CREATEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_CREATEDATABASEREQUEST.fields_by_name['database_spec']._options = None
_DELETEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_DELETEDATABASEREQUEST.fields_by_name['database_name']._options = None
_RESTOREDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_RESTOREDATABASEREQUEST.fields_by_name['database_name']._options = None
_RESTOREDATABASEREQUEST.fields_by_name['from_database']._options = None
_RESTOREDATABASEREQUEST.fields_by_name['backup_id']._options = None
_RESTOREDATABASEREQUEST.fields_by_name['time']._options = None
_RESTOREDATABASEMETADATA.fields_by_name['cluster_id']._options = None
_RESTOREDATABASEMETADATA.fields_by_name['database_name']._options = None
_RESTOREDATABASEMETADATA.fields_by_name['from_database']._options = None
_RESTOREDATABASEMETADATA.fields_by_name['backup_id']._options = None
_IMPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._options = None
_IMPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._options = None
_IMPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._options = None
_IMPORTDATABASEBACKUPREQUEST.fields_by_name['files']._options = None
_IMPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._options = None
_IMPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._options = None
_IMPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._options = None
_EXPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._options = None
_EXPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._options = None
_EXPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._options = None
_EXPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._options = None
_EXPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._options = None
_EXPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._options = None

_DATABASESERVICE = _descriptor.ServiceDescriptor(
  name='DatabaseService',
  full_name='yandex.cloud.mdb.sqlserver.v1.DatabaseService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1927,
  serialized_end=3397,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.sqlserver.v1.DatabaseService.Get',
    index=0,
    containing_service=None,
    input_type=_GETDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2._DATABASE,
    serialized_options=b'\202\323\344\223\002C\022A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.sqlserver.v1.DatabaseService.List',
    index=1,
    containing_service=None,
    input_type=_LISTDATABASESREQUEST,
    output_type=_LISTDATABASESRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/mdb/sqlserver/v1/clusters/{cluster_id}/databases',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.sqlserver.v1.DatabaseService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026\"1/mdb/sqlserver/v1/clusters/{cluster_id}/databases:\001*\262\322*\"\n\026CreateDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Restore',
    full_name='yandex.cloud.mdb.sqlserver.v1.DatabaseService.Restore',
    index=3,
    containing_service=None,
    input_type=_RESTOREDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/databases:restore:\001*\262\322*#\n\027RestoreDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ImportBackup',
    full_name='yandex.cloud.mdb.sqlserver.v1.DatabaseService.ImportBackup',
    index=4,
    containing_service=None,
    input_type=_IMPORTDATABASEBACKUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002=\"8/mdb/sqlserver/v1/clusters/{cluster_id}/databases:import:\001*\262\322*(\n\034ImportDatabaseBackupMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExportBackup',
    full_name='yandex.cloud.mdb.sqlserver.v1.DatabaseService.ExportBackup',
    index=5,
    containing_service=None,
    input_type=_EXPORTDATABASEBACKUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002M\"H/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}:export:\001*\262\322*(\n\034ExportDatabaseBackupMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.sqlserver.v1.DatabaseService.Delete',
    index=6,
    containing_service=None,
    input_type=_DELETEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002C*A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATABASESERVICE)

DESCRIPTOR.services_by_name['DatabaseService'] = _DATABASESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/resourcemanager/v1/cloud.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/resourcemanager/v1/cloud.proto',
  package='yandex.cloud.resourcemanager.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+yandex/cloud/resourcemanager/v1/cloud.proto\x12\x1fyandex.cloud.resourcemanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf2\x01\n\x05\x43loud\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x17\n\x0forganization_id\x18\x06 \x01(\t\x12\x42\n\x06labels\x18\x07 \x03(\x0b\x32\x32.yandex.cloud.resourcemanager.v1.Cloud.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42z\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanagerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_CLOUD_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.resourcemanager.v1.Cloud.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.resourcemanager.v1.Cloud.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.resourcemanager.v1.Cloud.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=356,
)

_CLOUD = _descriptor.Descriptor(
  name='Cloud',
  full_name='yandex.cloud.resourcemanager.v1.Cloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.resourcemanager.v1.Cloud.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.resourcemanager.v1.Cloud.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.resourcemanager.v1.Cloud.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.resourcemanager.v1.Cloud.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.resourcemanager.v1.Cloud.organization_id', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.resourcemanager.v1.Cloud.labels', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLOUD_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=356,
)

_CLOUD_LABELSENTRY.containing_type = _CLOUD
_CLOUD.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLOUD.fields_by_name['labels'].message_type = _CLOUD_LABELSENTRY
DESCRIPTOR.message_types_by_name['Cloud'] = _CLOUD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cloud = _reflection.GeneratedProtocolMessageType('Cloud', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CLOUD_LABELSENTRY,
    '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.Cloud.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CLOUD,
  '__module__' : 'yandex.cloud.resourcemanager.v1.cloud_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.resourcemanager.v1.Cloud)
  })
_sym_db.RegisterMessage(Cloud)
_sym_db.RegisterMessage(Cloud.LabelsEntry)


DESCRIPTOR._options = None
_CLOUD_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/customer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/customer.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&yandex/cloud/billing/v1/customer.proto\x12\x17yandex.cloud.billing.v1\"2\n\x08\x43ustomer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\t\"\x9b\x01\n\x0e\x43ustomerPerson\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08longname\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x11\n\tpost_code\x18\x05 \x01(\t\x12\x14\n\x0cpost_address\x18\x06 \x01(\t\x12\x15\n\rlegal_address\x18\x07 \x01(\t\x12\x0b\n\x03tin\x18\x08 \x01(\tBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
)




_CUSTOMER = _descriptor.Descriptor(
  name='Customer',
  full_name='yandex.cloud.billing.v1.Customer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.Customer.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.Customer.billing_account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=117,
)


_CUSTOMERPERSON = _descriptor.Descriptor(
  name='CustomerPerson',
  full_name='yandex.cloud.billing.v1.CustomerPerson',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.billing.v1.CustomerPerson.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longname', full_name='yandex.cloud.billing.v1.CustomerPerson.longname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phone', full_name='yandex.cloud.billing.v1.CustomerPerson.phone', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='yandex.cloud.billing.v1.CustomerPerson.email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_code', full_name='yandex.cloud.billing.v1.CustomerPerson.post_code', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='post_address', full_name='yandex.cloud.billing.v1.CustomerPerson.post_address', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legal_address', full_name='yandex.cloud.billing.v1.CustomerPerson.legal_address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tin', full_name='yandex.cloud.billing.v1.CustomerPerson.tin', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=275,
)

DESCRIPTOR.message_types_by_name['Customer'] = _CUSTOMER
DESCRIPTOR.message_types_by_name['CustomerPerson'] = _CUSTOMERPERSON
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Customer = _reflection.GeneratedProtocolMessageType('Customer', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMER,
  '__module__' : 'yandex.cloud.billing.v1.customer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.Customer)
  })
_sym_db.RegisterMessage(Customer)

CustomerPerson = _reflection.GeneratedProtocolMessageType('CustomerPerson', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMERPERSON,
  '__module__' : 'yandex.cloud.billing.v1.customer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.CustomerPerson)
  })
_sym_db.RegisterMessage(CustomerPerson)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/apigateway/v1/apigateway.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/apigateway/v1/apigateway.proto',
  package='yandex.cloud.serverless.apigateway.v1',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.serverless.apigateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/v1;apigateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/serverless/apigateway/v1/apigateway.proto\x12%yandex.cloud.serverless.apigateway.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\"\xb3\x05\n\nApiGateway\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12M\n\x06labels\x18\x07 \x03(\x0b\x32=.yandex.cloud.serverless.apigateway.v1.ApiGateway.LabelsEntry\x12H\n\x06status\x18\x08 \x01(\x0e\x32\x38.yandex.cloud.serverless.apigateway.v1.ApiGateway.Status\x12\x0e\n\x06\x64omain\x18\t \x01(\t\x12\x14\n\x0clog_group_id\x18\n \x01(\t\x12O\n\x10\x61ttached_domains\x18\x0b \x03(\x0b\x32\x35.yandex.cloud.serverless.apigateway.v1.AttachedDomain\x12I\n\x0c\x63onnectivity\x18\x0c \x01(\x0b\x32\x33.yandex.cloud.serverless.apigateway.v1.Connectivity\x12\x46\n\x0blog_options\x18\r \x01(\x0b\x32\x31.yandex.cloud.serverless.apigateway.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\"\\\n\x0e\x41ttachedDomain\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x0e\n\x06\x64omain\x18\x05 \x01(\t\"5\n\x0c\x43onnectivity\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x03(\t\"\x96\x01\n\nLogOptions\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12\x16\n\x0clog_group_id\x18\x02 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x03 \x01(\tH\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stinationB\x81\x01\n)yandex.cloud.api.serverless.apigateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/v1;apigatewayb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2.DESCRIPTOR,])



_APIGATEWAY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=766,
  serialized_end=863,
)
_sym_db.RegisterEnumDescriptor(_APIGATEWAY_STATUS)


_APIGATEWAY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=764,
)

_APIGATEWAY = _descriptor.Descriptor(
  name='ApiGateway',
  full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.labels', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.status', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.domain', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.log_group_id', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_domains', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.attached_domains', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connectivity', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.connectivity', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_options', full_name='yandex.cloud.serverless.apigateway.v1.ApiGateway.log_options', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_APIGATEWAY_LABELSENTRY, ],
  enum_types=[
    _APIGATEWAY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=863,
)


_ATTACHEDDOMAIN = _descriptor.Descriptor(
  name='AttachedDomain',
  full_name='yandex.cloud.serverless.apigateway.v1.AttachedDomain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain_id', full_name='yandex.cloud.serverless.apigateway.v1.AttachedDomain.domain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.serverless.apigateway.v1.AttachedDomain.certificate_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.serverless.apigateway.v1.AttachedDomain.enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='yandex.cloud.serverless.apigateway.v1.AttachedDomain.domain', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=865,
  serialized_end=957,
)


_CONNECTIVITY = _descriptor.Descriptor(
  name='Connectivity',
  full_name='yandex.cloud.serverless.apigateway.v1.Connectivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.serverless.apigateway.v1.Connectivity.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.serverless.apigateway.v1.Connectivity.subnet_id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1012,
)


_LOGOPTIONS = _descriptor.Descriptor(
  name='LogOptions',
  full_name='yandex.cloud.serverless.apigateway.v1.LogOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yandex.cloud.serverless.apigateway.v1.LogOptions.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.serverless.apigateway.v1.LogOptions.log_group_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.apigateway.v1.LogOptions.folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_level', full_name='yandex.cloud.serverless.apigateway.v1.LogOptions.min_level', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='destination', full_name='yandex.cloud.serverless.apigateway.v1.LogOptions.destination',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1015,
  serialized_end=1165,
)

_APIGATEWAY_LABELSENTRY.containing_type = _APIGATEWAY
_APIGATEWAY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_APIGATEWAY.fields_by_name['labels'].message_type = _APIGATEWAY_LABELSENTRY
_APIGATEWAY.fields_by_name['status'].enum_type = _APIGATEWAY_STATUS
_APIGATEWAY.fields_by_name['attached_domains'].message_type = _ATTACHEDDOMAIN
_APIGATEWAY.fields_by_name['connectivity'].message_type = _CONNECTIVITY
_APIGATEWAY.fields_by_name['log_options'].message_type = _LOGOPTIONS
_APIGATEWAY_STATUS.containing_type = _APIGATEWAY
_LOGOPTIONS.fields_by_name['min_level'].enum_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2._LOGLEVEL_LEVEL
_LOGOPTIONS.oneofs_by_name['destination'].fields.append(
  _LOGOPTIONS.fields_by_name['log_group_id'])
_LOGOPTIONS.fields_by_name['log_group_id'].containing_oneof = _LOGOPTIONS.oneofs_by_name['destination']
_LOGOPTIONS.oneofs_by_name['destination'].fields.append(
  _LOGOPTIONS.fields_by_name['folder_id'])
_LOGOPTIONS.fields_by_name['folder_id'].containing_oneof = _LOGOPTIONS.oneofs_by_name['destination']
DESCRIPTOR.message_types_by_name['ApiGateway'] = _APIGATEWAY
DESCRIPTOR.message_types_by_name['AttachedDomain'] = _ATTACHEDDOMAIN
DESCRIPTOR.message_types_by_name['Connectivity'] = _CONNECTIVITY
DESCRIPTOR.message_types_by_name['LogOptions'] = _LOGOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApiGateway = _reflection.GeneratedProtocolMessageType('ApiGateway', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _APIGATEWAY_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.apigateway.v1.apigateway_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.v1.ApiGateway.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _APIGATEWAY,
  '__module__' : 'yandex.cloud.serverless.apigateway.v1.apigateway_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.v1.ApiGateway)
  })
_sym_db.RegisterMessage(ApiGateway)
_sym_db.RegisterMessage(ApiGateway.LabelsEntry)

AttachedDomain = _reflection.GeneratedProtocolMessageType('AttachedDomain', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHEDDOMAIN,
  '__module__' : 'yandex.cloud.serverless.apigateway.v1.apigateway_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.v1.AttachedDomain)
  })
_sym_db.RegisterMessage(AttachedDomain)

Connectivity = _reflection.GeneratedProtocolMessageType('Connectivity', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIVITY,
  '__module__' : 'yandex.cloud.serverless.apigateway.v1.apigateway_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.v1.Connectivity)
  })
_sym_db.RegisterMessage(Connectivity)

LogOptions = _reflection.GeneratedProtocolMessageType('LogOptions', (_message.Message,), {
  'DESCRIPTOR' : _LOGOPTIONS,
  '__module__' : 'yandex.cloud.serverless.apigateway.v1.apigateway_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.v1.LogOptions)
  })
_sym_db.RegisterMessage(LogOptions)


DESCRIPTOR._options = None
_APIGATEWAY_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
